from ._core import load

from ._accessors import _nxrDataArray, _nxrDataset
